Package: muttest
Type: Package
Title: Mutation Testing
Version: 0.3.0
Authors@R: c(
    person(
      "Jakub", "Sobolewski",
      email = "jakupsob@gmail.com",
      role = c("aut", "cre")
    )
  )
Description: Measure quality of your tests.
    'muttest' introduces small changes (mutations) to your code
    and runs your tests to check if they catch the changes.
    If they do, your tests are good.
    If not, your assertions are not specific enough.
    'muttest' gives you percent score of how often your tests catch the changes.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (>= 4.1.0)
Imports: checkmate, cli, digest, fs, htmltools, jsonlite, mirai, R6,
        rlang, testthat, tools, treesitter, treesitter.r (>= 1.3.0),
        withr
Config/testthat/edition: 3
URL: https://jakubsob.github.io/muttest/
Suggests: box, covr, cucumber (>= 2.1.0), ggplot2, jsonvalidate, knitr,
        purrr, rmarkdown, shiny, stringr
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-07-21 12:13:22 UTC; runner
Author: Jakub Sobolewski [aut, cre]
Maintainer: Jakub Sobolewski <jakupsob@gmail.com>
Repository: CRAN
Date/Publication: 2026-07-21 12:30:19 UTC
Built: R 4.6.1; ; 2026-07-21 17:06:25 UTC; unix
