# Generated by roxygen2: do not edit by hand

S3method(print,muttest_plan)
S3method(print,muttest_result)
export(CopyStrategy)
export(FileTestStrategy)
export(FullTestStrategy)
export(JSONMutationReporter)
export(MultiReporter)
export(MutationReporter)
export(Mutator)
export(PackageCopyStrategy)
export(ProgressMutationReporter)
export(TestStrategy)
export(arithmetic_operators)
export(boolean_literal)
export(boolean_literals)
export(call_name)
export(comparison_operators)
export(condition_mutations)
export(default_copy_strategy)
export(default_reporter)
export(default_test_strategy)
export(delete_statement)
export(index_decrement)
export(index_increment)
export(index_mutations)
export(logical_operators)
export(muttest)
export(muttest_plan)
export(na_literal)
export(na_literals)
export(negate_condition)
export(numeric_decrement)
export(numeric_increment)
export(numeric_literals)
export(operator)
export(remove_condition_negation)
export(remove_negation)
export(replace_return_value)
export(report)
export(string_empty)
export(string_fill)
export(string_literals)
import(testthat)
importFrom(R6,R6Class)
importFrom(cli,col_green)
importFrom(cli,col_grey)
importFrom(cli,col_red)
importFrom(cli,col_yellow)
importFrom(cli,symbol)
importFrom(digest,digest)
importFrom(rlang,`%||%`)
importFrom(tools,file_path_sans_ext)
